rm(list=ls())
library(fields)
require(graphics)
require(maps)
library(ncdf4)
library(mapdata)
library(RColorBrewer)

####################
df<-read.table("/gpfs/ahrenshsmfs02/share/temp/IPCC_PAPER/MedCORDEX/PLOTS/Vb/Vb_1950-2005_VbH2019_ICCP.txt")
#####    READ ACCORDING TO THE YEAR, MONTH,Vb-ID
year<-as.numeric(format(as.Date(df[,5], format="%Y-%m-%d"),"%Y"))
month<-as.numeric(format(as.Date(df[,5], format="%Y-%m-%d"),"%m"))
Vb_ID<-df[,1]

#####   COunting the  Vb events in historical perid ######
events_num<-numeric()
hist_years<-seq(1951,2005,1)
for(i in 1:55){
events_num[i]<-length(unique(Vb_ID[which(year==hist_years[i])]))
}
df2<-read.table("/gpfs/ahrenshsmfs02/share/temp/IPCC_PAPER/MedCORDEX/PLOTS/Vb/Vb_2015-2099_VbH2019_ICCP.txt")
#####    READ ACCORDING TO THE YEAR, MONTH,Vb-ID
year<-as.numeric(format(as.Date(df2[,5], format="%Y-%m-%d"),"%Y"))
month<-as.numeric(format(as.Date(df2[,5], format="%Y-%m-%d"),"%m"))
Vb_ID<-df2[,1]
#####   COunting the  Vb events in historical perid ######
events_num_p<-numeric()
fut_years<-seq(2045,2099,1)
for(i in 1:55){
events_num_p[i]<-length(unique(Vb_ID[which(year==fut_years[i])]))
}



dfr<-read.table("/gpfs/ahrenshsmfs02/share/temp/IPCC_PAPER/MedCORDEX/PLOTS/Vb/Vb_1901-2010_H2019_05_CCLM+NEMO_ERA20C.txt")
year<-as.numeric(format(as.Date(dfr[,5], format="%d/%m/%Y"),"%Y"))
events_num_r<-numeric();
Vb_ID<-dfr[,1]
rea_years<-seq(1951,2005,1)
for(i in 1:55){
events_num_r[i]<-length(unique(Vb_ID[which(year==rea_years[i])]))
}
################

library(ggplot2)
years_h<-seq(1951,2005,1)
years_p<-seq(2045,2099,1)
df<-data.frame(events_num_r,events_num,events_num_p)

p1<-ggplot(df, aes(x = years_h, y = events_num_r),col="red") + geom_bar(stat = "identity") + geom_smooth(method = "lm") + labs(title="GUF Evaluation",
        x ="Years", y = "Number of Events",hjust = 0.5) +  ylim(0, 22) + theme(plot.title = element_text(hjust = 0.5,face = "bold"))


p2<-ggplot(df, aes(x = years_h, y = events_num),col="red") + geom_bar(stat = "identity") + geom_smooth(method = "lm") + labs(title="GUF Historical",
        x ="Years", y = "Number of Events",hjust = 0.5) +  ylim(0, 22) + theme(plot.title = element_text(hjust = 0.5,face = "bold"))

p3<-ggplot(df, aes(x = years_p, y = events_num_p),col="red") + geom_bar(stat = "identity") + geom_smooth(method = "lm") + labs(title="GUF Future",
        x ="Years", y = "Number of Events",hjust = 0.5) +  ylim(0, 22) + theme(plot.title = element_text(hjust = 0.5,face = "bold"))



library(grid)
pdf("events_plots_years.pdf",width=12,height=4)
grid.newpage()
pushViewport(viewport(layout = grid.layout(nrow = 1, ncol = 3)))
define_region <- function(row, col){
 viewport(layout.pos.row = row, layout.pos.col = col)}

print(p1, vp = define_region(row = 1, col = 1))
print(p2, vp = define_region(row = 1, col = 2))
print(p3, vp = define_region(row = 1, col = 3))

dev.off()



######   Significance test #####

func_perc_change<-function(new,old){((new-old)/old) * 100}
func_SE_mean<-function(x){var(x)/sqrt(length(x))}
fun_SE_percentage <-function(mean_new,mean_old,se_new,se_old){ abs(mean_new/mean_old)  * sqrt( (se_new^2 / mean_new^2) + (se_old^2 / mean_old^2)) *100 }

#######   Mean of the Number of Events Per Year #####

events_per_year_rea    <-  mean(events_num_r)
events_per_year_hist   <-  mean(events_num)
events_per_year_fut    <-  mean(events_num_p)

####   Mean  Percentage Change  ####

per_change_hist_rea   <-  func_perc_change(events_per_year_hist,events_per_year_rea)

per_change_fut_hist   <-  func_perc_change(events_per_year_fut,events_per_year_hist)

####   Standard Errors 
se_events_per_year_rea    <- func_SE_mean(events_num_r)
se_events_per_year_hist   <- func_SE_mean(events_num)
se_events_per_year_fut    <- func_SE_mean(events_num_p)

####################  Standard Error Percentage Chnage #####

se_change_hist_rea      <-  fun_SE_percentage (events_per_year_hist,events_per_year_rea,se_events_per_year_hist,se_events_per_year_rea)

se_per_change_fut_hist  <-  fun_SE_percentage (events_per_year_fut,events_per_year_hist,se_events_per_year_fut,se_events_per_year_hist)

#trail      <-fun_SE_percentage(6613917,6429326,83537,36768)
#trail2     <-fun_SE_percentage(10.12727,9.654545,1.633334,2.128565)
################    Lower Bound  & Upper Bound for Percentage Chaange    ###


lower_bound_hist_rea  <-  per_change_hist_rea - (1.65*se_change_hist_rea)

upper_bound_hist_rea  <-  per_change_hist_rea + (1.65*se_change_hist_rea)

###########

lower_bound_fut_hist  <-  per_change_fut_hist - (1.65*se_per_change_fut_hist)

upper_bound_fut_hist  <- per_change_fut_hist +  (1.65*se_per_change_fut_hist)

##############

